@@ -82,7 +82,7 @@ class SubmitCommand:
       self.queryJobs            = []
       self.killJobs             = []
       self.venueStatus          = ""
-      self.venue                = ""
+      self.venues               = []
       self.inputFiles           = []
       self.parameters           = []
       self.dataFile             = ""
@@ -595,7 +595,7 @@ class SubmitCommand:
       """
       setError = False
       if self.__isArgString(venue):
-         self.venue = venue
+         self.venues = [venue]
       else:
          self.logger.log(logging.ERROR,getLogMessage("venue must be a string"))
          setError = True
@@ -603,30 +603,56 @@ class SubmitCommand:
       return(setError)
 
 
-   def resetVenue(self):
+   def __loadVenue(self):
+      self.resetVenues()
+      if 'venue' in self.savedCommand:
+         self.setVenues(self.savedCommand['venue'])
+
+
+   def setVenues(self,
+                 venues):
       """
-      Remove venue setting from submit command.
+      Supply set of venues for submit run.
+      venues can be specified as a single destination or
+      of list of destinations.
+      """
+      setError = False
+      if   self.__isArgString(venues):
+         self.venues = [venues]
+      elif isinstance(venues,list):
+         self.venues = copy.copy(venues)
+      else:
+         self.logger.log(logging.ERROR,getLogMessage("venues must be a string or list"))
+         setError = True
+
+      return(setError)
+
+
+   def resetVenues(self):
+      """
+      Remove venues from submit run.
       """
       resetError = False
-      self.venue = ""
+      self.venues = []
 
       return(resetError)
 
 
-   def __addVenueArgs(self):
-      if self.venue:
-         self.args += ['--venue',self.venue]
+   def __addVenuesArgs(self):
+      if self.venues:
+         for venue in self.venues:
+            self.args += ['--venue',venue]
 
 
-   def __saveVenue(self):
-      if self.venue:
-         self.savedCommand['venue'] = self.venue
+   def __saveVenues(self):
+      if self.venues:
+         self.savedCommand['venues'] = copy.copy(self.venues)
 
 
-   def __loadVenue(self):
-      self.resetVenue()
-      if 'venue' in self.savedCommand:
-         self.setVenue(self.savedCommand['venue'])
+   def __loadVenues(self):
+      self.resetVenues()
+      if 'venues' in self.savedCommand:
+         self.setVenues(self.savedCommand['venues'])
 
 
    def setInputFiles(self,
@@ -1821,7 +1847,7 @@ class SubmitCommand:
                if self.local:
                   self.__addLocalArg()
                else:
-                  self.__addVenueArgs()
+                  self.__addVenuesArgs()
                   self.__addNcoresArgs()
                   self.__addPPNArgs()
                   self.__addWallTimeArgs()
@@ -1853,7 +1879,7 @@ class SubmitCommand:
       self.__resetQueryJobs()
       self.__resetKillJobs()
       self.__resetVenueStatus()
-      self.__resetVenue()
+      self.__resetVenues()
       self.__resetInputFiles()
       self.__resetDefaultSeparator()
       self.__resetParameters()
@@ -1896,7 +1922,7 @@ class SubmitCommand:
       self.__saveQueryJobs()
       self.__saveKillJobs()
       self.__saveVenueStatus()
-      self.__saveVenue()
+      self.__saveVenues()
       self.__saveInputFiles()
       self.__saveDefaultSeparator()
       self.__saveParameters()
@@ -1975,6 +2001,7 @@ class SubmitCommand:
          self.__loadKillJobs()
          self.__loadVenueStatus()
          self.__loadVenue()
+         self.__loadVenues()
          self.__loadInputFiles()
          self.__loadDefaultSeparator()
          self.__loadParameters()
